@@ -1,3 +1,4 @@
+#!/bin/bash
 # Add SKILL library
 mkdir -p "${PREFIX}/lib/skill/virtue"
 cp -rf "${RECIPE_DIR}/../virtue" \
@@ -15,4 +16,5 @@ cp "${RECIPE_DIR}/activate.sh" \
 cp "${RECIPE_DIR}/activate.csh" \
    "${PREFIX}/etc/conda/${CHANGE}.d/${PKG_NAME}_${CHANGE}.csh"
 
-PYTHON -m pip install . -vv
\ No newline at end of file
+flit build
+python -m pip install --no-deps dist/*.whl -vv
\ No newline at end of file
